# Pretty Json Parser
Easy generate apple watch and ios icons with one command.

## Install
```
pip install igenerate
```


## Usage
Only you have to one command:

```
usage: igenerate [iwatch|ios] [icon_path]

igenerate ios demo/luffy.jpg
igenerate iwatch demo/luffy.jpg

```
and all done.